==> savane-3.11.tar.gz: savane-3.11/frontend/php/link-to-projects.php <==
<?php # -*- PHP -*-
# Group homepage.
#
# Copyright (C) 1999-2000 The SourceForge Crew
# Copyright (C) 2000-2003 Free Software Foundation
# Copyright (C) 2002-2005 Mathieu Roy <yeupou--gnu.org>
# Copyright (C) 2007 Sylvain Beucler
# Copyright (C) 2018, 2023 Ineiev
#
# This file is part of Savane.
#
# Savane is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Savane is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# The context of this page cannot be guessed later, we have to hardcode it.
define ('CONTEXT', 'project');
require_once ('include/init.php');

# Extract the group name.
$pathinfo = basename (preg_replace ("/\?.*/", "", $_SERVER['REQUEST_URI']));

$res_grp = db_execute (
  "SELECT * FROM groups WHERE unix_group_name = ?", [$pathinfo]
);

if (db_numrows ($res_grp) < 1)
  {
    print db_error ();
    exit_error (_("Invalid Group"), _("That group does not exist."));
  }

$group = $pathinfo;
$extra_script_name = "/$pathinfo";
$group_id = db_result ($res_grp, 0, 'group_id');

$project = new Project ($group_id);

require ('include/project_home.php');
?>

==> savane-3.12.tar.gz: savane-3.12/frontend/php/link-to-projects.php <==
<?php # -*- PHP -*-
# Group homepage.
#
# Copyright (C) 1999, 2000 The SourceForge Crew
# Copyright (C) 2000-2006 Free Software Foundation, Inc.
# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
# Copyright (C) 2014, 2016, 2017 Assaf Gordon
# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
# Copyright (C) 2013, 2014, 2017-2023 Ineiev
#
# This file is part of Savane.
#
# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
# under the terms of the GNU General Public license version 3 or (at your
# option) any later version; further contributions are covered by
# the GNU Affero General Public license version 3 or (at your option)
# any later version.  The license notices for the AGPL and the GPL follow.
#
# Savane is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Savane is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Savane is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Savane is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# The context of this page cannot be guessed later, we have to hardcode it.
define ('CONTEXT', 'project');
require_once ('include/init.php');

# Extract the group name.
$pathinfo = basename (preg_replace ("/\?.*/", "", $_SERVER['REQUEST_URI']));

$res_grp = db_execute (
  "SELECT * FROM groups WHERE unix_group_name = ?", [$pathinfo]
);

if (db_numrows ($res_grp) < 1)
  {
    print db_error ();
    exit_error (_("Invalid Group"), _("That group does not exist."));
  }

$group = $pathinfo;
$extra_script_name = "/$pathinfo";
$group_id = db_result ($res_grp, 0, 'group_id');

$project = new Project ($group_id);

require ('include/project_home.php');
?>
